@@ -1,9 +1,9 @@
 use nix::ifaddrs::*;
-use nix::poll::*;
 use nix::sys::socket::AddressFamily;
 use nix::sys::socket::SockaddrLike;
 use nix::sys::socket::SockaddrStorage;
-use nix::sys::time::TimeSpec;
+use nix::sys::stat::fstat;
+use nix::sys::stat::SFlag;
 use std::collections::HashMap;
 use std::fmt;
 use std::net::Ipv4Addr;
@@ -11,7 +11,6 @@ use std::net::Ipv6Addr;
 use std::net::ToSocketAddrs;
 use std::os::unix::io::RawFd;
 use std::str::FromStr;
-use std::time::Duration;
 
 #[derive(Debug, PartialEq, PartialOrd, Hash, Eq, Clone)]
 pub enum Addr {
@@ -119,21 +118,15 @@ pub fn parse_mask(mask: &str) -> Option<u32> {
 
 pub fn parse_v6(address: &str, input_base: Option<i32>, reverse: bool) -> Option<Addr> {
     match input_base {
-        Some(base) => {
-            if base == 10 {
-                return Some(Addr::V6(Ipv6Addr::from(
-                    match u128::from_str_radix(address, base as u32) {
-                        Ok(y) => y,
-                        Err(e) => {
-                            eprintln!("cannot convert {}: {}", address, e);
-                            return None;
-                        }
-                    },
-                )));
-            }
-
-            None
-        }
+        Some(base) => Some(Addr::V6(Ipv6Addr::from(
+            match u128::from_str_radix(address, base as u32) {
+                Ok(y) => y,
+                Err(e) => {
+                    eprintln!("cannot convert {}: {}", address, e);
+                    return None;
+                }
+            },
+        ))),
         None => match Ipv6Addr::from_str(address) {
             Ok(mut i) => {
                 if reverse {
@@ -268,7 +261,7 @@ pub fn parse_address_mask(
 
     for p in ["https://", "http://", "ftp://", "sftp://", "ftps://"] {
         if a.starts_with(p) {
-            let v: Vec<&str> = a.split( '/' ).collect();
+            let v: Vec<&str> = a.split('/').collect();
             arg = v[2];
             break;
         }
@@ -953,7 +946,7 @@ pub fn matching_network_interface(
 
                     if ip_only {
                         if let Addr::V4(x) = ip.address {
-                            if if_addr_bin == u32::from(x) {
+                            if u32::from(if_addr_bin) == u32::from(x) {
                                 return ifaddr.interface_name.to_string();
                             }
                         }
@@ -965,7 +958,7 @@ pub fn matching_network_interface(
                             let bin = u32::from(x);
                             let a = netmask.as_sockaddr_in().unwrap().ip();
 
-                            if (bin & a) == (if_addr_bin & a) {
+                            if (bin & u32::from(a)) == (u32::from(if_addr_bin) & u32::from(a)) {
                                 //println!("{:#?} in {} {}", ip, bin, a);
                                 return ifaddr.interface_name.to_string();
                             }
@@ -1014,7 +1007,7 @@ pub fn rbl_format(ip: &Ip) -> String {
         Addr::V6(x) => {
             let mut v = vec![];
             let octet = x.octets();
-            for (_, o) in octet.iter().rev().enumerate() {
+            for o in octet.iter().rev() {
                 let r = format!("{:02x}", o);
 
                 v.push(r.get(1..2).unwrap().to_string());
@@ -1263,23 +1256,12 @@ pub fn format_details(
 }
 
 pub fn fd_ready(fd: RawFd) -> bool {
-    let opfds: Vec<PollFd> = vec![PollFd::new(fd, PollFlags::POLLIN | PollFlags::POLLNVAL)];
-
-    let mut pfds = opfds;
-    let ts = TimeSpec::from(Duration::new(0, 0));
-    match ppoll(&mut pfds, Some(ts), None) {
-        Ok(x) => {
-            if x == 0 {
-                if let Some(ev) = pfds[0].revents() {
-                    if ev | PollFlags::POLLNVAL == PollFlags::POLLNVAL {
-                        return true;
-                    }
-                }
-                false
-            } else {
-                true
-            }
+    let s = fstat(fd);
+    if let Ok(x) = s {
+        if SFlag::S_IFIFO.bits() & x.st_mode == SFlag::S_IFIFO.bits() {
+            return true;
         }
-        Err(_x) => false,
     }
+
+    false
 }
