@@ -206,8 +206,9 @@ fn process_input_file(
     let mut used: HashMap<Addr, bool> = HashMap::new();
     if matches.opt_present("available") {
         for line in reader.lines() {
+            let line: String = line.as_ref().unwrap().trim().to_string();
             let ip = match parse_address_mask(
-                line.as_ref().unwrap(),
+                line.as_ref(),
                 Some(32),
                 Some(128),
                 input_base,
@@ -215,7 +216,7 @@ fn process_input_file(
             ) {
                 Some(x) => x,
                 None => {
-                    eprintln!("Could not parse {}", &line.as_ref().unwrap());
+                    eprintln!("Could not parse {}", line);
                     continue;
                 }
             };
@@ -233,8 +234,9 @@ fn process_input_file(
     if matches.opt_present("encapsulating") {
         let mut used: HashMap<Ip, bool> = HashMap::new();
         for line in reader.lines() {
+            let line: String = line.as_ref().unwrap().trim().to_string();
             let ip = match parse_address_mask(
-                line.as_ref().unwrap(),
+                line.as_ref(),
                 Some(32),
                 Some(128),
                 input_base,
@@ -242,7 +244,7 @@ fn process_input_file(
             ) {
                 Some(x) => x,
                 None => {
-                    eprintln!("Could not parse {}", &line.as_ref().unwrap());
+                    eprintln!("Could not parse {}", line);
                     continue;
                 }
             };
@@ -262,9 +264,12 @@ fn process_input_file(
         std::process::exit(0);
     }
 
+    let mut found_match = false;
+
     for line in reader.lines() {
+        let line: String = line.as_ref().unwrap().trim().to_string();
         let ip = parse_address_mask(
-            &line.unwrap(),
+            &line,
             Some(32),
             Some(128),
             input_base,
@@ -285,6 +290,7 @@ fn process_input_file(
                 }
 
                 if found {
+                    found_match = true;
                     print_details(&ip.unwrap(), matches, rows, None);
                 }
             }
@@ -299,6 +305,7 @@ fn process_input_file(
                 }
 
                 if !found {
+                    found_match = true;
                     print_details(&ip.unwrap(), matches, rows, None);
                 }
             }
@@ -307,6 +314,10 @@ fn process_input_file(
             }
         }
     }
+
+    if !found_match && inside.is_some() {
+        std::process::exit(1);
+    }
 }
 
 fn wait_stdin(matches: &getopts::Matches) -> bool {
@@ -314,11 +325,12 @@ fn wait_stdin(matches: &getopts::Matches) -> bool {
         return true;
     }
     if matches.opt_present("list")
-        || matches.opt_present("inside") || matches.opt_present("outside")
+        || matches.opt_present("inside")
+        || matches.opt_present("outside")
     {
         return true;
     }
-    if matches.free.is_empty() && matches.opt_present("divide") {
+    if matches.free.is_empty() {
         return true;
     }
     false
@@ -347,7 +359,7 @@ fn main() {
     opts.optflag(
         "e",
         "encapsulating",
-        "display encapsulating network from lookup list",
+        "display encapsulating network from arguments or lookup list",
     );
 
     opts.optopt("f", "format", "format output\n'cidr' expands to %a/%c\\n\n'short' expands to %a\\n\nSee manual for more options", "STRING");
@@ -518,6 +530,8 @@ fn main() {
         }
     }
 
+    let mut used: HashMap<Ip, bool> = HashMap::new();
+
     for arg in &ip_args {
         match arg.address {
             Addr::V4(_) => {
@@ -534,9 +548,27 @@ fn main() {
             }
         }
 
+        if matches.opt_present("encapsulating") {
+            used.insert(arg.clone(), true);
+            continue;
+        }
         print_details(arg, &matches, &rows, None);
     }
 
+    if matches.opt_present("encapsulating") {
+        match smallest_group_network(&used) {
+            Some(x) => {
+                print_details(&x, &matches, &rows, None);
+            }
+            None => {
+                eprintln!("Could not find an encapsulating network, sorry");
+                std::process::exit(1);
+            }
+        }
+
+        std::process::exit(0);
+    }
+
     if ip_args.is_empty() {
         println!("{}", opts.usage("ripcalc"));
         eprintln!("Need to provide v4 or v6 address.");
