@@ -249,7 +249,7 @@ mod test {
             cidr: 30,
         };
 
-        let mut i = addresses(&net, None);
+        let mut i = addresses(&net, None, None);
 
         assert_eq!(
             i.next().as_ref().unwrap().address,
@@ -417,7 +417,7 @@ update IP6 set active = 0 where (ip >= 42540724579414763292693624807812497408 an
         hm.insert(Addr::V4(Ipv4Addr::from_str("192.168.0.1").unwrap()), true);
         hm.insert(Addr::V4(Ipv4Addr::from_str("192.168.0.2").unwrap()), true);
 
-        let mut i = addresses(&net, Some(&hm));
+        let mut i = addresses(&net, Some(&hm), None);
 
         assert_eq!(
             i.next().as_ref().unwrap().address,
@@ -431,7 +431,7 @@ update IP6 set active = 0 where (ip >= 42540724579414763292693624807812497408 an
         hm.insert(Addr::V4(Ipv4Addr::from_str("192.168.1.1").unwrap()), true);
         hm.insert(Addr::V4(Ipv4Addr::from_str("192.168.1.2").unwrap()), true);
 
-        let mut i = addresses(&net, Some(&hm));
+        let mut i = addresses(&net, Some(&hm), None);
 
         assert_eq!(
             i.next().as_ref().unwrap().address,
@@ -639,8 +639,171 @@ update IP6 set active = 0 where (ip >= 42540724579414763292693624807812497408 an
         let f = format_details(&net, "%La".to_string(), &None);
         assert_eq!(f, Some("-5192296858534827628530496329154561".to_string()));
         let f = format_details(&net, "%la".to_string(), &None);
-        assert_eq!(f, Some("340277174624079928635746076935439056895".to_string()));
+        assert_eq!(
+            f,
+            Some("340277174624079928635746076935439056895".to_string())
+        );
     }
 
+    #[test]
+    fn test_within_ipv4() {
+        assert_eq!(
+            within(
+                &Ip {
+                    address: Addr::V4(Ipv4Addr::from_str("127.0.0.1").unwrap()),
+                    cidr: 8
+                },
+                &Ip {
+                    address: Addr::V4(Ipv4Addr::from_str("10.0.0.0").unwrap()),
+                    cidr: 8
+                },
+            ),
+            false
+        );
+        assert_eq!(
+            within(
+                &Ip {
+                    address: Addr::V4(Ipv4Addr::from_str("192.168.0.0").unwrap()),
+                    cidr: 24
+                },
+                &Ip {
+                    address: Addr::V4(Ipv4Addr::from_str("192.168.0.0").unwrap()),
+                    cidr: 16
+                },
+            ),
+            false
+        );
+        assert_eq!(
+            within(
+                &Ip {
+                    address: Addr::V4(Ipv4Addr::from_str("127.0.0.1").unwrap()),
+                    cidr: 8
+                },
+                &Ip {
+                    address: Addr::V4(Ipv4Addr::from_str("192.168.0.0").unwrap()),
+                    cidr: 16
+                },
+            ),
+            false
+        );
+        assert_eq!(
+            within(
+                &Ip {
+                    address: Addr::V4(Ipv4Addr::from_str("127.0.0.1").unwrap()),
+                    cidr: 8
+                },
+                &Ip {
+                    address: Addr::V4(Ipv4Addr::from_str("127.1.1.1").unwrap()),
+                    cidr: 16
+                },
+            ),
+            true
+        );
+    }
+    #[test]
+    fn test_within_ipv6() {
+        assert_eq!(
+            within(
+                &Ip {
+                    address: Addr::V6(Ipv6Addr::from_str("::1").unwrap()),
+                    cidr: 48
+                },
+                &Ip {
+                    address: Addr::V6(Ipv6Addr::from_str("f::1").unwrap()),
+                    cidr: 48
+                },
+            ),
+            false
+        );
+        assert_eq!(
+            within(
+                &Ip {
+                    address: Addr::V6(Ipv6Addr::from_str("::1").unwrap()),
+                    cidr: 48
+                },
+                &Ip {
+                    address: Addr::V6(Ipv6Addr::from_str("dead:beef::cafe").unwrap()),
+                    cidr: 48
+                },
+            ),
+            false
+        );
+        assert_eq!(
+            within(
+                &Ip {
+                    address: Addr::V6(Ipv6Addr::from_str("1::1").unwrap()),
+                    cidr: 48
+                },
+                &Ip {
+                    address: Addr::V6(Ipv6Addr::from_str("::f:f:f:f:f").unwrap()),
+                    cidr: 48
+                },
+            ),
+            false
+        );
+    }
 
+    #[test]
+    fn test_network_divide_iter() {
+        let net = Ip {
+            address: Addr::V4(Ipv4Addr::from_str("192.168.0.0").unwrap()),
+            cidr: 24,
+        };
+
+        let mut i = addresses(&net, None, Some(25));
+        assert_eq!(
+            i.next().as_ref().unwrap().address,
+            Addr::V4(Ipv4Addr::from_str("192.168.0.0").unwrap())
+        );
+        assert_eq!(
+            i.next().as_ref().unwrap().address,
+            Addr::V4(Ipv4Addr::from_str("192.168.0.128").unwrap())
+        );
+        assert_eq!(i.next(), None,);
+
+        let mut i = addresses(&net, None, Some(26));
+        assert_eq!(
+            i.next().as_ref().unwrap().address,
+            Addr::V4(Ipv4Addr::from_str("192.168.0.0").unwrap())
+        );
+        assert_eq!(
+            i.next().as_ref().unwrap().address,
+            Addr::V4(Ipv4Addr::from_str("192.168.0.64").unwrap())
+        );
+        assert_eq!(
+            i.next().as_ref().unwrap().address,
+            Addr::V4(Ipv4Addr::from_str("192.168.0.128").unwrap())
+        );
+        assert_eq!(
+            i.next().as_ref().unwrap().address,
+            Addr::V4(Ipv4Addr::from_str("192.168.0.192").unwrap())
+        );
+        assert_eq!(i.next(), None,);
+    }
+
+    #[test]
+    fn test_network_divide_iter_v6() {
+        let net = Ip {
+            address: Addr::V6(Ipv6Addr::from_str("::1").unwrap()),
+            cidr: 48,
+        };
+
+        let mut i = addresses(&net, None, Some(64));
+        assert_eq!(
+            i.next().as_ref().unwrap().address,
+            Addr::V6(Ipv6Addr::from_str("::").unwrap())
+        );
+        assert_eq!(
+            i.next().as_ref().unwrap().address,
+            Addr::V6(Ipv6Addr::from_str("0:0:0:1::").unwrap())
+        );
+        assert_eq!(
+            i.next().as_ref().unwrap().address,
+            Addr::V6(Ipv6Addr::from_str("0:0:0:2::").unwrap())
+        );
+
+        let i = addresses(&net, None, Some(64));
+        let v: Vec<Ip> = i.collect();
+        assert_eq!(v.len(), 65536);
+    }
 }
